@@ -19,7 +19,7 @@
 ##
 ## Compute the gray-level co-occurrence matrix (GLCM) for an image.
 ##
-## @code{graycomatrix} calculates the GLCM for the input image @var{I}. The GLCM
+## @code{graycomatrix} calculates the GLCM for the input image @var{img}. The GLCM
 ## is a statistical method of examining the textures that considers the spatial
 ## relationship of pixels.
 ##
@@ -45,10 +45,10 @@
 ## The image is scaled to have integer values between1 and the number of levels.
 ##
 ## @item 'GrayLimits'
-## A two-element vector [low high] that specifies the intensity values in @var{I}
+## A two-element vector [low high] that specifies the intensity values in @var{img}
 ## that are to be considered when scaling the image to the number of levels.
-## The default is the range of the class of @var{I}. if [] is used as input,
-## the graylimits are [min(I(:)) max(I(:))].
+## The default is the range of the class of @var{img}. if [] is used as input,
+## the graylimits are [min(img(:)) max(img(:))].
 ##
 ## @item 'Symmetric'
 ## A logical value indicating whether the GLCM should be symmetric. If true,
@@ -56,7 +56,7 @@
 ## false.
 ##
 ## @item 'use_oct'
-## A logical value indicating whether the GLCM computation will use oct fiie.
+## A logical value indicating whether the GLCM computation will use oct file.
 ## If true the GLCM is computed using cpp code and oct interface.
 ## If false, the computation is done using Octave function compute_glcm.
 ## The default is true. The oct computation is a little bit faster,
@@ -92,19 +92,19 @@ function [glcm, scaled_image] = graycomatrix (img, varargin)
   persistent first_time;
   if isempty(first_time)
     first_time = false;
-    disp("graycomatrix has been re-written. If you want the previous version, please run graycomatrix_old");
+    disp("graycomatrix has been re-written. If you want to use the previous version, please run graycomatrix_old");
   endif
 
   if (nargin == 0)
     print_usage ();
   elseif (! isimage(img))
     error ("graycomatrix: first argument must be an image")
-  elseif (numel(size(img)) > 2)
-    error ("graycomatrix: img should be 2D image")
+  elseif (ndims(img) > 2)
+    error ("graycomatrix: img should be a 2D image")
   endif
 
   # Parse inputs
-  params = parse_gaycomatrix_inputs (img, varargin{:});
+  params = parse_graycomatrix_inputs (img, varargin{:});
 
   # Compute scaled image
   scaled_image = compute_scaled_image (img, params);
@@ -120,7 +120,7 @@ function [glcm, scaled_image] = graycomatrix (img, varargin)
 endfunction
 
 
-function params = parse_gaycomatrix_inputs (I, varargin)
+function params = parse_graycomatrix_inputs (I, varargin)
 
   #   parse input params
   p = inputParser;
@@ -462,7 +462,7 @@ endfunction
 %!error <graycomatrix: first argument must be an image> graycomatrix("xxx")
 %!error <graycomatrix: first argument must be an image> graycomatrix([])
 %!error graycomatrix(1, 2)
-%!error <graycomatrix: img should be 2D image> graycomatrix(cat(3, [1 2], [1 2], [1 2]))
+%!error <graycomatrix: img should be a 2D image> graycomatrix(cat(3, [1 2], [1 2], [1 2]))
 %!error <graycomatrix: argument 'AAA' is not a > graycomatrix([1, 2], "AAA")
 %!error <graycomatrix: failed validation of> graycomatrix(phantom(), "GrayLimits", 0)
 %!error <graycomatrix: failed validation of> graycomatrix(phantom(), "GrayLimits", "aa")
